# sophisticate


[![PyPI version](https://badge.fury.io/py/sophisticate.svg)](https://badge.fury.io/py/sophisticate)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


## This library will install the following libraries 


### conf-mat    : https://pypi.org/project/conf-mat/
### linkedit    : https://pypi.org/project/linkedit/
### cqueue      : https://pypi.org/project/cqueue/
### lstack      : https://pypi.org/project/lstack/
### hashall     : https://pypi.org/project/hashall/
### thri        : https://pypi.org/project/thri/
### heep        : https://pypi.org/project/heep/
### hashtbl     : https://pypi.org/project/hashtbl/
### court-queue : https://pypi.org/project/court-queue/
### ntwrk       : https://pypi.org/project/ntwrk/
### vsort       : https://pypi.org/project/vsort/
### dictQ       : https://pypi.org/project/dictQ/


## Installation


You can install `sophisticate` via pip:


```bash
pip install sophisticate
```


## License


This project is licensed under the MIT LICENSE - see the [LICENSE](https://opensource.org/licenses/MIT) for more details.
